@@ -1,5 +1,5 @@
 package Server::Control::t::Base;
-use base qw(Server::Control::Test::Class);
+use base qw(Test::Class);
 use File::Slurp;
 use File::Temp qw(tempdir);
 use Guard;
